@@ -10,4 +10,8 @@ class ClientError(Error):
 
 class ImageError(Error):
     """Raised when the Image Returned is not valid"""
+    pass
+
+class ServerNotResponsiveError(Error):
+    """Raised when the target Server is not online / Unavailable"""
     pass
\ No newline at end of file
